<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="作业类型" prop="jobType">
        <el-select v-model="formData.jobType" placeholder="请选择作业类型">
          <el-option label="请选择字典生成" value="" />
        </el-select>
      </el-form-item>
      <el-form-item label="医生编号" prop="docId">
        <el-input v-model="formData.docId" placeholder="请输入医生编号" />
      </el-form-item>
      <el-form-item label="医生名称" prop="docName">
        <el-input v-model="formData.docName" placeholder="请输入医生名称" />
      </el-form-item>
      <el-form-item label="设备编号" prop="devId">
        <el-input v-model="formData.devId" placeholder="请输入设备编号" />
      </el-form-item>
      <el-form-item label="患者编号" prop="patId">
        <el-input v-model="formData.patId" placeholder="请输入患者编号" />
      </el-form-item>
      <el-form-item label="患者名称" prop="patName">
        <el-input v-model="formData.patName" placeholder="请输入患者名称" />
      </el-form-item>
      <el-form-item label="作业时间" prop="jobTime">
        <el-date-picker
          v-model="formData.jobTime"
          type="date"
          value-format="x"
          placeholder="选择作业时间"
        />
      </el-form-item>
      <el-form-item label="作业概要" prop="summary">
        <el-input v-model="formData.summary" placeholder="请输入作业概要" />
      </el-form-item>
      <el-form-item label="备注" prop="remark">
        <el-input v-model="formData.remark" placeholder="请输入备注" />
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { JobRecordApi, JobRecordVO } from '@/api/ecg/jobrecord'

/** 工作记录 表单 */
defineOptions({ name: 'JobRecordForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  jobType: undefined,
  docId: undefined,
  docName: undefined,
  devId: undefined,
  patId: undefined,
  patName: undefined,
  jobTime: undefined,
  summary: undefined,
  remark: undefined
})
const formRules = reactive({
  jobType: [{ required: true, message: '作业类型不能为空', trigger: 'change' }],
  docId: [{ required: true, message: '医生编号不能为空', trigger: 'blur' }]
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await JobRecordApi.getJobRecord(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as JobRecordVO
    if (formType.value === 'create') {
      await JobRecordApi.createJobRecord(data)
      message.success(t('common.createSuccess'))
    } else {
      await JobRecordApi.updateJobRecord(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    jobType: undefined,
    docId: undefined,
    docName: undefined,
    devId: undefined,
    patId: undefined,
    patName: undefined,
    jobTime: undefined,
    summary: undefined,
    remark: undefined
  }
  formRef.value?.resetFields()
}
</script>